spoon

Package spoon |
[hide private]
[frames] | no frames]

# Package spoon

source code

Submodules | [hide private]
spoon.ber: The low level BER based encoding used by spoon to serialize objects. spoon.ber.common spoon.ber.stream spoon.ber.tag spoon.messaging spoon.messaging.decorators spoon.messaging.messagingcore spoon.nulllogger spoon.objTypes spoon.routing spoon.routing.meshrouter: Mesh Routing, this is the protocol by which an ad-hoc network of nodes can be created and how messages may be passed between them. spoon.spooncore spoon.spoonstream spoon.transports: Subpackage for link related objects. spoon.transports.spoontransport spoon.transports.transporthub

Classes | [hide private]
`` | Serial
`` | serialprop When used like a property in a Serial class, it will act as a flag to the serializer that only properties that are of type `serialprop` or `lazyprop` are to be serialized.
`` | lazyprop When used like a property in a Serial class, it will act as a flag to the serializer that only properties that are of type `serialprop` or `lazyprop` are to be serialized.
`` | SpoonStream SpoonStream implements an object stream.
`` | NullLogger Dummy logging object.
`` | x Dummy logging object.

Variables | [hide private]
`` | __author__ = `'Matt Sullivan <matts@zarrf.com>'`
`` | __date__ = `'22 Nov 2006'`
`` | __version__ = `'0.1.1'`
`` | __version_info__ = `(0, 1, 1)`
`` | __license__ = `'MIT/X Consortium'`

Variables Details | [hide private]

    ### __author__ None Value:
        'Matt Sullivan <matts@zarrf.com>'

    ### __date__ None Value:
        '22 Nov 2006'

    ### __version__ None Value:
        '0.1.1'

    ### __version_info__ None Value:
        (0, 1, 1)

    ### __license__ None Value:
        'MIT/X Consortium'